@@ -6,10 +6,11 @@ import json
 from http import HTTPStatus
 
 from flask import make_response
-from flask_openapi3 import OpenAPI, APIBlueprint
-from flask_openapi3.models import Info
 from pydantic import BaseModel, Field
 
+from flask_openapi3 import Info
+from flask_openapi3 import OpenAPI, APIBlueprint
+
 app = OpenAPI(__name__, info=Info(title="Hello API", version="1.0.0"), )
 
 bp = APIBlueprint("Hello BP", __name__)
@@ -33,6 +34,16 @@ def hello(path: HelloPath):
     return response
 
 
+@bp.get("/hello_no_response/<string:name>", responses={"204": None})
+def hello_no_response(path: HelloPath):
+    message = {"message": f"""Hello {path.name}!"""}
+
+    # This message will never be returned because the http code (NO_CONTENT) doesn't return anything
+    response = make_response(message, HTTPStatus.NO_CONTENT)
+    response.mimetype = "application/json"
+    return response
+
+
 app.register_api(bp)
 
 if __name__ == "__main__":
