@@ -6,9 +6,10 @@ from typing import Optional, List
 
 from pydantic import BaseModel, Field
 
-from flask_openapi3 import Info, Tag
+from flask_openapi3 import Info, Tag, Server
 from flask_openapi3 import OpenAPI
-from flask_openapi3.models.security import HTTPBearer, OAuth2, OAuthFlows, OAuthFlowImplicit, APIKey, HTTPBase
+from flask_openapi3 import ExternalDocumentation, ExtraRequestBody, Example
+from flask_openapi3 import HTTPBearer, OAuth2, OAuthFlows, OAuthFlowImplicit, APIKey, HTTPBase
 
 info = Info(title='book API', version='1.0.0')
 basic = HTTPBase()
@@ -39,11 +40,9 @@ security = [
     {"basic": []}
 ]
 
-app.config["FLASK_OPENAPI_VALIDATE_RESPONSE"] = True
-
 
 class BookPath(BaseModel):
-    bid: int = Field(..., description='book id')
+    bid: int = Field(..., description='book id', deprecated=True, example=100)
 
 
 class BookQuery(BaseModel):
@@ -73,9 +72,15 @@ class BookResponse(BaseModel):
     tags=[book_tag],
     summary='new summary',
     description='new description',
+    operation_id="get_book_id",
+    external_docs=ExternalDocumentation(
+        url="https://www.openapis.org/",
+        description="Something great got better, get excited!"),
+
     responses={"200": BookResponse},
     extra_responses={"200": {"content": {"text/csv": {"schema": {"type": "string"}}}}},
-    security=security
+    security=security,
+    servers=[Server(url="https://www.openapis.org/", description="openapi")]
 )
 def get_book(path: BookPath):
     """Get book
@@ -104,7 +109,32 @@ def get_books(query: BookQuery):
     }
 
 
-@app.post('/book', tags=[book_tag], responses={"200": BookResponse})
+extra_body = ExtraRequestBody(
+    description="This is post RequestBody",
+    required=True,
+    example="ttt",
+    examples={
+        "example1": Example(
+            summary="example summary1",
+            description="example description1",
+            value={
+                "age": 24,
+                "author": "author1"
+            }
+        ),
+        "example2": Example(
+            summary="example summary2",
+            description="example description2",
+            value={
+                "age": 48,
+                "author": "author2"
+            }
+        )
+    }
+)
+
+
+@app.post('/book', tags=[book_tag], responses={"200": BookResponse}, extra_body=extra_body)
 def create_book(body: BookBody):
     print(body)
     return {"code": 0, "message": "ok"}, HTTPStatus.OK
