@@ -3,20 +3,18 @@
 # @Time    : 2022/4/1 16:54
 import json
 from json import JSONDecodeError
-from typing import Dict, Any, Type, Callable
+from typing import Any, Type, Callable
 
-from flask import request, make_response, current_app
+from flask import request, make_response
 from flask.wrappers import Response
 from pydantic import ValidationError, BaseModel
 from pydantic.error_wrappers import ErrorWrapper
 
-from .utils import validate_response
-
 
 def _do_header(header, request_kwargs):
     request_headers = dict(request.headers) or {}
     for key, value in header.__annotations__.items():
-        key_title = key.title()
+        key_title = key.replace("_", "-").title()
         # add original key
         if key_title in request_headers.keys():
             request_headers[key] = request_headers[key_title]
@@ -91,7 +89,6 @@ def _do_body(body, request_kwargs):
 def _do_wrapper(
         func: Callable,
         *,
-        responses: Dict[str, Type[BaseModel]] = None,
         header: Type[BaseModel] = None,
         cookie: Type[BaseModel] = None,
         path: Type[BaseModel] = None,
@@ -137,8 +134,4 @@ def _do_wrapper(
     # handle request
     response = func(**request_kwargs)
 
-    is_validate_response = current_app.config.get("FLASK_OPENAPI_VALIDATE_RESPONSE", False)
-    if is_validate_response and responses:
-        validate_response(response, responses)
-
     return response
