@@ -4,18 +4,16 @@
 
 import inspect
 import re
-from http import HTTPStatus
-from typing import Dict, Type, Callable, List, Tuple, Any, ForwardRef
+from typing import Dict, Type, Callable, List, Tuple, Any, ForwardRef, Optional
 
 import pydantic.typing
-from flask import Response as _Response, current_app
 from pydantic import BaseModel
 
 from .http import HTTP_STATUS, HTTPMethod
 from .models import OPENAPI3_REF_TEMPLATE, OPENAPI3_REF_PREFIX, Tag
-from .models.common import Schema, Response, MediaType
-from .models.parameter import ParameterInType, Parameter
-from .models.path import Operation, RequestBody, PathItem
+from .models.common import Schema, MediaType, Encoding, ExtraRequestBody
+from .models.path import Operation, RequestBody, PathItem, Response
+from .models.path import ParameterInType, Parameter
 from .models.validation_error import UnprocessableEntity
 
 
@@ -31,7 +29,8 @@ def get_operation(func: Callable, *, summary: str = None, description: str = Non
         doc_description = "</br>".join(lines) or None
     operation = Operation(
         summary=summary or doc_summary,
-        description=description or doc_description
+        description=description or doc_description,
+        responses={}
     )
 
     return operation
@@ -76,7 +75,6 @@ def parse_header(header: Type[BaseModel]) -> Tuple[List[Parameter], dict]:
     parameters = []
     components_schemas = dict()
     properties = schema.get("properties", {})
-    definitions = schema.get("definitions", {})
 
     for name, value in properties.items():
         data = {
@@ -86,11 +84,10 @@ def parse_header(header: Type[BaseModel]) -> Tuple[List[Parameter], dict]:
             "required": name in schema.get("required", []),
             "schema": Schema(**value)
         }
+        # parse extra values
+        data.update(**value)
         parameters.append(Parameter(**data))
 
-    for name, value in definitions.items():
-        components_schemas[name] = Schema(**value)
-
     return parameters, components_schemas
 
 
@@ -100,7 +97,6 @@ def parse_cookie(cookie: Type[BaseModel]) -> Tuple[List[Parameter], dict]:
     parameters = []
     components_schemas = dict()
     properties = schema.get("properties", {})
-    definitions = schema.get("definitions", {})
 
     for name, value in properties.items():
         data = {
@@ -110,11 +106,10 @@ def parse_cookie(cookie: Type[BaseModel]) -> Tuple[List[Parameter], dict]:
             "required": name in schema.get("required", []),
             "schema": Schema(**value)
         }
+        # parse extra values
+        data.update(**value)
         parameters.append(Parameter(**data))
 
-    for name, value in definitions.items():
-        components_schemas[name] = Schema(**value)
-
     return parameters, components_schemas
 
 
@@ -124,7 +119,6 @@ def parse_path(path: Type[BaseModel]) -> Tuple[List[Parameter], dict]:
     parameters = []
     components_schemas = dict()
     properties = schema.get("properties", {})
-    definitions = schema.get("definitions", {})
 
     for name, value in properties.items():
         data = {
@@ -134,11 +128,10 @@ def parse_path(path: Type[BaseModel]) -> Tuple[List[Parameter], dict]:
             "required": True,
             "schema": Schema(**value)
         }
+        # parse extra values
+        data.update(**value)
         parameters.append(Parameter(**data))
 
-    for name, value in definitions.items():
-        components_schemas[name] = Schema(**value)
-
     return parameters, components_schemas
 
 
@@ -148,7 +141,6 @@ def parse_query(query: Type[BaseModel]) -> Tuple[List[Parameter], dict]:
     parameters = []
     components_schemas = dict()
     properties = schema.get("properties", {})
-    definitions = schema.get("definitions", {})
 
     for name, value in properties.items():
         data = {
@@ -158,20 +150,21 @@ def parse_query(query: Type[BaseModel]) -> Tuple[List[Parameter], dict]:
             "required": name in schema.get("required", []),
             "schema": Schema(**value)
         }
+        # parse extra values
+        data.update(**value)
         parameters.append(Parameter(**data))
 
-    for name, value in definitions.items():
-        components_schemas[name] = Schema(**value)
-
     return parameters, components_schemas
 
 
-def parse_form(form: Type[BaseModel]) -> Tuple[Dict[str, MediaType], dict]:
+def parse_form(
+        form: Type[BaseModel],
+        extra_form: Optional[ExtraRequestBody] = None,
+) -> Tuple[Dict[str, MediaType], dict]:
     """Parse form model"""
     schema = get_schema(form)
     components_schemas = dict()
     properties = schema.get("properties", {})
-    definitions = schema.get("definitions", {})
 
     assert properties, f"{form.__name__}'s properties cannot be empty."
 
@@ -180,28 +173,34 @@ def parse_form(form: Type[BaseModel]) -> Tuple[Dict[str, MediaType], dict]:
     encoding = {}
     for k, v in properties.items():
         if v.get("type") == "array":
-            encoding[k] = {"style": "form"}
-
-    content = {
-        "multipart/form-data": MediaType(
-            **{
-                "schema": Schema(
-                    **{
-                        "$ref": f"{OPENAPI3_REF_PREFIX}/{title}"
-                    }
-                ),
-                "encoding": encoding
-            }
-        )
-    }
-
-    for name, value in definitions.items():
-        components_schemas[name] = Schema(**value)
+            encoding[k] = Encoding(style="form")
+    if extra_form:
+        # update encoding
+        if extra_form.encoding:
+            encoding.update(**extra_form.encoding)
+        content = {
+            "multipart/form-data": MediaType(
+                schema=Schema(**{"$ref": f"{OPENAPI3_REF_PREFIX}/{title}"}),
+                example=extra_form.example,
+                examples=extra_form.examples,
+                encoding=encoding or None
+            )
+        }
+    else:
+        content = {
+            "multipart/form-data": MediaType(
+                schema=Schema(**{"$ref": f"{OPENAPI3_REF_PREFIX}/{title}"}),
+                encoding=encoding or None
+            )
+        }
 
     return content, components_schemas
 
 
-def parse_body(body: Type[BaseModel]) -> Tuple[Dict[str, MediaType], dict]:
+def parse_body(
+        body: Type[BaseModel],
+        extra_body: Optional[ExtraRequestBody] = None,
+) -> Tuple[Dict[str, MediaType], dict]:
     """Parse body model"""
     schema = get_schema(body)
     components_schemas = dict()
@@ -209,18 +208,21 @@ def parse_body(body: Type[BaseModel]) -> Tuple[Dict[str, MediaType], dict]:
 
     title = schema.get("title")
     components_schemas[title] = Schema(**schema)
-
-    content = {
-        "application/json": MediaType(
-            **{
-                "schema": Schema(
-                    **{
-                        "$ref": f"{OPENAPI3_REF_PREFIX}/{title}"
-                    }
-                )
-            }
-        )
-    }
+    if extra_body:
+        content = {
+            "application/json": MediaType(
+                schema=Schema(**{"$ref": f"{OPENAPI3_REF_PREFIX}/{title}"}),
+                example=extra_body.example,
+                examples=extra_body.examples,
+                encoding=extra_body.encoding
+            )
+        }
+    else:
+        content = {
+            "application/json": MediaType(
+                schema=Schema(**{"$ref": f"{OPENAPI3_REF_PREFIX}/{title}"})
+            )
+        }
 
     for name, value in definitions.items():
         components_schemas[name] = Schema(**value)
@@ -294,16 +296,12 @@ def get_responses(
     # handle extra_responses
     for key, value in extra_responses.items():
         # key "200" value {"content":{"text/csv":{"schema":{"type": "string"}}}}
-        extra_content = value.get("content", {})
-        if extra_content:
-            # {"text/csv":{"schema":{"type": "string"}}}
-            if _responses.get(key) and isinstance(extra_content, dict):
-                _responses[key].content.update(**extra_content)  # noqa
-            else:
-                _responses[key] = Response(
-                    description=HTTP_STATUS.get(key, ""),
-                    content=extra_content
-                )
+        new_response = Response(
+            # Best effort to ensure there is always a description
+            description=value.pop("description", HTTP_STATUS.get(key, "")),
+            **value
+        )
+        _responses[key] = new_response.merge_with(_responses.get(key))
 
     components_schemas.update(**_schemas)
     operation.responses = _responses
@@ -313,43 +311,6 @@ def validate_responses_type(responses: Dict[str, Any]) -> None:
     assert isinstance(responses, dict), f"{responses} invalid `dict`"
 
 
-def validate_response(resp: Any, responses: Dict[str, Type[BaseModel]]) -> None:
-    """Validate response"""
-    if not current_app.config.get("FLASK_OPENAPI_DISABLE_WARNINGS", False):
-        print("Warning: "
-              "You are using `FLASK_OPENAPI_VALIDATE_RESPONSE=True`, "
-              "please do not use it in the production environment, "
-              "because it will reduce the performance. "
-              "Note, you can disable this warning with `Flask.config['FLASK_OPENAPI_DISABLE_WARNINGS'] = True`")
-    if isinstance(resp, tuple):  # noqa
-        _resp, status_code = resp[:2]
-    elif isinstance(resp, _Response):
-        if resp.mimetype != "application/json":
-            # only application/json
-            return
-            # raise TypeError("`Response` mimetype must be application/json.")
-        _resp, status_code = resp.json, resp.status_code  # noqa
-    else:
-        _resp, status_code = resp, 200
-    # status_code is http.HTTPStatus
-    if isinstance(status_code, HTTPStatus):
-        status_code = status_code.value
-
-    resp_model = responses.get(str(status_code))
-    if resp_model is None:
-        return
-    assert inspect.isclass(resp_model) and \
-           issubclass(resp_model, BaseModel), f"{resp_model} is invalid `pydantic.BaseModel`"
-    try:
-        if resp_model.__custom_root_type__:
-            # https://pydantic-docs.helpmanual.io/usage/models/#custom-root-types
-            resp_model(__root__=_resp)
-        else:
-            resp_model(**_resp)
-    except TypeError:
-        raise TypeError(f"`{resp_model.__name__}` validation failed, must be a mapping.")
-
-
 def parse_and_store_tags(
         new_tags: List[Tag] = None,
         old_tags: List[Tag] = None,
@@ -374,12 +335,16 @@ def parse_and_store_tags(
 def parse_parameters(
         func: Callable,
         *,
+        extra_form: Optional[ExtraRequestBody] = None,
+        extra_body: Optional[ExtraRequestBody] = None,
         components_schemas: dict = None,
         operation: Operation = None,
         doc_ui: bool = True,
 ) -> Tuple[Type[BaseModel], Type[BaseModel], Type[BaseModel], Type[BaseModel], Type[BaseModel], Type[BaseModel]]:
     """
-    :param func: flask view func
+    :param func: Flask view func
+    :param extra_form: Extra information describing the request body(application/form).
+    :param extra_body: Extra information describing the request body(application/json).
     :param components_schemas: `models.component.py` Components.schemas
     :param operation: `models.path.py` Operation
     :param doc_ui: add openapi document UI(swagger and redoc). Defaults to True.
@@ -412,19 +377,31 @@ def parse_parameters(
         parameters.extend(_parameters)
         components_schemas.update(**_components_schemas)
     if form:
-        _content, _components_schemas = parse_form(form)
+        _content, _components_schemas = parse_form(form, extra_form)
         components_schemas.update(**_components_schemas)
-        requestBody = RequestBody(**{
-            "content": _content,
-        })
-        operation.requestBody = requestBody
+        if extra_form:
+            request_body = RequestBody(
+                description=extra_form.description,
+                content=_content,
+                required=extra_form.required
+            )
+        else:
+            request_body = RequestBody(**{
+                "content": _content,
+            })
+        operation.requestBody = request_body
     if body:
-        _content, _components_schemas = parse_body(body)
+        _content, _components_schemas = parse_body(body, extra_body)
         components_schemas.update(**_components_schemas)
-        requestBody = RequestBody(**{
-            "content": _content,
-        })
-        operation.requestBody = requestBody
+        if extra_body:
+            request_body = RequestBody(
+                description=extra_body.description,
+                content=_content,
+                required=extra_body.required
+            )
+        else:
+            request_body = RequestBody(content=_content)
+        operation.requestBody = request_body
     operation.parameters = parameters if parameters else None
 
     return header, cookie, path, query, form, body
